@@ -54,6 +54,7 @@ test_that("mlr3spatiotempcv indices are the same as blockCV indices: selection =
 
   task = test_make_blockCV_test_task()
 
+  set.seed(42)
   rsmp = rsmp("spcv_block",
     range = 50000L,
     selection = "checkerboard",
@@ -62,14 +63,21 @@ test_that("mlr3spatiotempcv indices are the same as blockCV indices: selection =
 
   testSF = test_make_blockCV_test_df()
 
-  capture.output(testBlock <- suppressMessages(
-    suppressWarnings(blockCV::spatialBlock(
-      speciesData = testSF,
-      theRange = 50000L,
+  # set.seed(42)
+  testBlock = suppressWarnings(suppressMessages(
+    blockCV::cv_spatial(
+      x = testSF,
+      size = 50000L,
+      k = 2,
       selection = "checkerboard",
-      showBlocks = FALSE))))
+      hexagon = FALSE,
+      plot = FALSE,
+      report = FALSE,
+      progress = FALSE,
+      verbose = FALSE
+  )))
 
-  expect_equal(rsmp$instance$fold, testBlock$foldID)
+  expect_equal(rsmp$instance$fold, testBlock$folds_ids)
 })
 
 test_that("mlr3spatiotempcv indices are the same as blockCV indices: cols and rows", {
@@ -79,7 +87,6 @@ test_that("mlr3spatiotempcv indices are the same as blockCV indices: cols and ro
 
   sf::sf_use_s2(use_s2 = FALSE)
 
-  set.seed(42)
   rsmp = rsmp("spcv_block",
     folds = 5,
     rows = 3,
@@ -88,59 +95,81 @@ test_that("mlr3spatiotempcv indices are the same as blockCV indices: cols and ro
 
   testSF = test_make_blockCV_test_df()
 
-  set.seed(42)
-  capture.output(testBlock <- suppressMessages(
-    blockCV::spatialBlock(
-      speciesData = testSF,
+  testBlock = suppressMessages(
+    blockCV::cv_spatial(
+      x = testSF,
       k = 5,
-      rows = 3,
-      cols = 4,
-      showBlocks = FALSE,
+      rows_cols = c(3, 4),
+      hexagon = FALSE,
+      plot = FALSE,
       verbose = FALSE,
-      progress = FALSE)
+      report = FALSE,
+      progress = FALSE
   ))
 
-  expect_equal(rsmp$instance$fold, testBlock$foldID)
+  expect_equal(rsmp$instance$fold, testBlock$folds_ids)
 })
 
-test_that("mlr3spatiotempcv indices are the same as blockCV indices: rasterLayer", {
+test_that("mlr3spatiotempcv indices are the same as blockCV indices: spatRaster", {
   skip_if_not_installed("sf")
   skip_if_not_installed("terra")
 
-  # cran test failure (Error: no arguments in initialization list)
-  testthat::skip_on_os("solaris")
   # same issue on macOS 3.6
   testthat::skip_if(as.numeric(R.version$major) < 4)
 
-  set.seed(42)
-
   task = test_make_blockCV_test_task()
   testSF = test_make_blockCV_test_df()
 
-  rl = raster::raster(raster::extent(testSF), crs = raster::crs(testSF))
-  vals = seq_len(raster::ncell(rl))
-  rl = raster::setValues(rl, vals)
+  spatras = terra::rast(testSF)
+  vals = seq_len(terra::ncell(spatras))
+  terra::setValues(spatras, vals)
 
+  set.seed(42)
   rsmp1 = rsmp("spcv_block",
     range = 50000L,
     folds = 2,
-    selection = "checkerboard",
-    rasterLayer = rl)
+    selection = "random",
+    rasterLayer = spatras)
   rsmp1$instantiate(task)
 
+  set.seed(42)
   # blockCV
-  capture.output(testBlock <- suppressMessages(
+  testBlock = suppressMessages(
+    blockCV::cv_spatial(
+      x = testSF,
+      size = 50000L,
+      selection = "random",
+      r = spatras,
+      k = 2,
+      hexagon = FALSE,
+      plot = FALSE,
+      report = FALSE,
+      verbose = FALSE,
+      progress = FALSE
+  ))
+
+  rl = terra::rast(terra::ext(testSF), crs = terra::crs(testSF))
+  vals = seq_len(terra::ncell(rl))
+  rl = terra::setValues(rl, vals)
+
+  set.seed(42)
+  # blockCV OLD
+  testBlock_old = suppressMessages(
     blockCV::spatialBlock(
       speciesData = testSF,
       theRange = 50000L,
-      selection = "checkerboard",
+      selection = "random",
       rasterLayer = rl,
-      showBlocks = FALSE,
+      k = 2,
       verbose = FALSE,
-      progress = FALSE)
+      progress = FALSE,
+      showBlocks = FALSE
   ))
 
-  expect_equal(rsmp1$instance$fold, testBlock$foldID)
+  # tempcv vs blockCV (NEW)
+  expect_equal(rsmp1$instance$fold, testBlock$folds_ids)
+  # blockCV old vs blockCV NEW
+  expect_equal(testBlock_old$foldID, testBlock$folds_ids)
 })
 
 test_that("Error when selection = checkboard and folds > 2", {
